@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extensions-manager-ui.c,v 1.15 2005/10/23 10:43:10 jframeau Exp $
+ *  $Id: extensions-manager-ui.c,v 1.17 2005/12/02 12:50:17 chpe Exp $
  */
 
 #include "config.h"
@@ -79,14 +79,6 @@ enum
 	N_COLUMNS
 };
 
-/* glade callbacks */
-void extensions_manager_ui_response_cb (GtkWidget *button,
-					int response,
-				  	GObject *dialog);
-void extensions_manager_ui_info_dialog_response_cb (GtkWidget *button,
-						    int response,
-						    GObject *dialog);
-
 static void extensions_manager_ui_class_init	(ExtensionsManagerUIClass *klass);
 static void extensions_manager_ui_init		(ExtensionsManagerUI *dialog);
 
@@ -124,7 +116,7 @@ extensions_manager_ui_register_type (GTypeModule *module)
 	return type;
 }
 
-void
+static void
 extensions_manager_ui_response_cb (GtkWidget *widget,
 				   int response,
 				   GObject *dialog)
@@ -138,14 +130,6 @@ extensions_manager_ui_response_cb (GtkWidget *widget,
 	g_object_unref (dialog);
 }
 
-void
-extensions_manager_ui_info_dialog_response_cb (GtkWidget *widget,
-					       int response,
-					       GObject *dialog)
-{
-	g_object_unref (dialog);
-}
-
 static void
 show_extension_info (ExtensionsManagerUI *parent_dialog,
 		     EphyExtensionInfo *info)
@@ -167,6 +151,7 @@ show_extension_info (ExtensionsManagerUI *parent_dialog,
 
 	gtk_window_set_transient_for (GTK_WINDOW (dialog),
 				      GTK_WINDOW (parent_dialog->priv->window));
+	/* FIXME window group ! */
 	gtk_window_present (GTK_WINDOW (dialog));
 
 	g_free (name);
@@ -338,6 +323,9 @@ build_ui (ExtensionsManagerUI *dialog)
 	priv->treeview = ephy_dialog_get_control (EPHY_DIALOG (dialog),
 						  properties[PROP_TREEVIEW].id);
 
+	g_signal_connect (priv->window, "response",
+			  G_CALLBACK (extensions_manager_ui_response_cb), dialog);
+
 	gtk_window_set_icon_name (GTK_WINDOW (priv->window), GTK_STOCK_PREFERENCES);
 
 	treeview = GTK_TREE_VIEW (priv->treeview);
@@ -416,12 +404,14 @@ extension_removed_cb (EphyExtensionsManager *manager,
 
 static void
 extensions_manager_ui_init (ExtensionsManagerUI *dialog)
-{		
+{
+	ExtensionsManagerUIPrivate *priv;
+
 	LOG ("ExtensionsManagerUI initializing");
 
-	dialog->priv = EXTENSIONS_MANAGER_UI_GET_PRIVATE (dialog);
+	priv = dialog->priv = EXTENSIONS_MANAGER_UI_GET_PRIVATE (dialog);
 
-	dialog->priv->manager = EPHY_EXTENSIONS_MANAGER
+	priv->manager = EPHY_EXTENSIONS_MANAGER
 		(ephy_shell_get_extensions_manager (ephy_shell));
 
 	ephy_dialog_construct (EPHY_DIALOG (dialog),
@@ -432,13 +422,13 @@ extensions_manager_ui_init (ExtensionsManagerUI *dialog)
 
 	build_ui (dialog);
 
-	dialog->priv->added_signal =
+	priv->added_signal =
 		g_signal_connect (G_OBJECT (dialog->priv->manager), "added",
 				  G_CALLBACK (extension_added_cb), dialog);
-	dialog->priv->changed_signal =
+	priv->changed_signal =
 		g_signal_connect (G_OBJECT (dialog->priv->manager), "changed",
 				  G_CALLBACK (active_sync), dialog);
-	dialog->priv->removed_signal =
+	priv->removed_signal =
 		g_signal_connect (G_OBJECT (dialog->priv->manager), "removed",
 				  G_CALLBACK (extension_removed_cb), dialog);
 }
@@ -447,15 +437,16 @@ static void
 extensions_manager_ui_finalize (GObject *object)
 {
 	ExtensionsManagerUI *dialog = EXTENSIONS_MANAGER_UI (object);
+	ExtensionsManagerUIPrivate *priv = dialog->priv;	
 
 	LOG ("ExtensionsManagerUI finalising");
 
-	g_signal_handler_disconnect (G_OBJECT (dialog->priv->manager),
-				     dialog->priv->changed_signal);
-	g_signal_handler_disconnect (G_OBJECT (dialog->priv->manager),
-				     dialog->priv->added_signal);
-	g_signal_handler_disconnect (G_OBJECT (dialog->priv->manager),
-				     dialog->priv->removed_signal);
+	g_signal_handler_disconnect (G_OBJECT (priv->manager),
+				     priv->changed_signal);
+	g_signal_handler_disconnect (G_OBJECT (priv->manager),
+				     priv->added_signal);
+	g_signal_handler_disconnect (G_OBJECT (priv->manager),
+				     priv->removed_signal);
 
 	parent_class->finalize (object);
 }
