@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks.c,v 1.1.2.1 2004/09/26 16:22:39 chpe Exp $
+ *  $Id: smart-bookmarks.c,v 1.4 2005/01/28 22:30:33 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "smart-bookmarks-extension.h"
 #include "ephy-debug.h"
@@ -33,7 +31,7 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering Smart Bookmarks Extension")
+	LOG ("Registering Smart Bookmarks Extension");
 
 #ifdef ENABLE_NLS
 	/* Initialise the i18n stuff */
